#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-qq
version:              0.0.6
visibility:           public
id:                   string-qq-0.0.6-JP8n0z35sH6DYsTnW3W6cq
key:                  string-qq-0.0.6-JP8n0z35sH6DYsTnW3W6cq
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            unstable
synopsis:
    QuasiQuoter for non-interpolated strings, texts and bytestrings.

description:
    QuasiQuoter for non-interpolated strings, texts and bytestrings, useful for writing multi-line IsString literals.

category:             Data
abi:                  610ec3dd3b314c0c602e0e2adbdd14f5
exposed:              True
exposed-modules:      Data.String.QQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-qq-0.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-qq-0.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-qq-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-qq
hs-libraries:         HSstring-qq-0.0.6-JP8n0z35sH6DYsTnW3W6cq
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:   /usr/share/doc/haskell-string-qq/html/string-qq.haddock
haddock-html:         /usr/share/doc/haskell-string-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

